==> LLTestJavaSDK-0.0.2-sources.jar: io/github/kaposke/models/ArtifactResponse.java <==
package io.github.kaposke.models;

@lombok.Getter
@lombok.EqualsAndHashCode(callSuper = false)
@lombok.ToString
@com.fasterxml.jackson.annotation.JsonInclude(
  com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL
)
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(builder = ArtifactResponse.Builder.class)
public class ArtifactResponse extends io.github.kaposke.models.BaseModel {

  @lombok.Getter
  @lombok.EqualsAndHashCode(callSuper = false)
  @lombok.ToString
  @com.fasterxml.jackson.annotation.JsonInclude(
    com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL
  )
  @com.fasterxml.jackson.databind.annotation.JsonDeserialize(
    builder = ArtifactResponse.Doc.Builder.class
  )
  public static class Doc extends io.github.kaposke.models.BaseModel {

    @lombok.Getter
    @lombok.Setter
    @lombok.experimental.Accessors(chain = true)
    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(
      buildMethodName = "buildWithoutValidation",
      withPrefix = "set"
    )
    public static class Builder extends io.github.kaposke.models.BaseModel.Builder {

      static final java.util.Set<java.util.Set<String>> REQUIRED_FIELDS_GROUPS;

      static {
        java.lang.String[][] requiredFieldsGroups = new java.lang.String[][] {
          new java.lang.String[] {
            "artifactId",
            "createdAt",
            "fileLocation",
            "id",
            "previewSlug",
            "previewUrl",
            "updatedAt",
            "version",
          },
        };

        REQUIRED_FIELDS_GROUPS =
          java.util.Arrays
            .stream(requiredFieldsGroups)
            .map(group ->
              java.util.Arrays.stream(group).collect(java.util.stream.Collectors.toSet())
            )
            .collect(java.util.stream.Collectors.toSet());
      }

      @com.fasterxml.jackson.annotation.JsonProperty("approvedDocUrl")
      private java.lang.String approvedDocUrl;

      @com.fasterxml.jackson.annotation.JsonProperty("artifactId")
      private java.lang.Double artifactId;

      @com.fasterxml.jackson.annotation.JsonProperty("createdAt")
      private java.lang.String createdAt;

      @com.fasterxml.jackson.annotation.JsonProperty("fileLocation")
      private java.lang.String fileLocation;

      @com.fasterxml.jackson.annotation.JsonProperty("id")
      private java.lang.Double id;

      @com.fasterxml.jackson.annotation.JsonProperty("previewSlug")
      private java.lang.String previewSlug;

      @com.fasterxml.jackson.annotation.JsonProperty("previewUrl")
      private java.lang.String previewUrl;

      @com.fasterxml.jackson.annotation.JsonProperty("updatedAt")
      private java.lang.String updatedAt;

      @com.fasterxml.jackson.annotation.JsonProperty("version")
      private java.lang.String version;

      public Builder() {
        super(ValidationType.ALL_OF);
      }

      protected Builder(BaseModel.Builder.ValidationType validationType) {
        super(validationType);
      }

      public ArtifactResponse.Doc build() {
        String validateMsg = validate();

        if (validateMsg != null) {
          throw new io.github.kaposke.exceptions.ApiException(validateMsg);
        }

        return buildWithoutValidation();
      }

      public ArtifactResponse.Doc buildWithoutValidation() {
        return new ArtifactResponse.Doc(this);
      }

      @Override
      protected java.util.Set<String> getNonNullInstanceFieldNames() {
        // Introspect the class to get a list of all declared fields.
        return java.util.Arrays
          .asList(this.getClass().getDeclaredFields())
          .stream()
          .filter(field -> {
            try {
              // Filter fields that are non-static and have values that are not null.
              return (
                !java.lang.reflect.Modifier.isStatic(field.getModifiers()) &&
                field.get(this) != null
              );
            } catch (IllegalArgumentException | IllegalAccessException e) {
              // This should never happen...

              throw new io.github.kaposke.exceptions.ApiException(
                "Unexpected exception thrown while accessing instance fields.",
                e
              );
            }
          })
          .map(java.lang.reflect.Field::getName)
          .collect(java.util.stream.Collectors.toSet());
      }

      @Override
      protected java.util.Set<java.util.Set<String>> getRequiredFieldsGroups() {
        return REQUIRED_FIELDS_GROUPS;
      }
    }

    @com.fasterxml.jackson.annotation.JsonProperty("approvedDocUrl")
    private final java.lang.String approvedDocUrl;

    @com.fasterxml.jackson.annotation.JsonProperty("artifactId")
    private final java.lang.Double artifactId;

    @com.fasterxml.jackson.annotation.JsonProperty("createdAt")
    private final java.lang.String createdAt;

    @com.fasterxml.jackson.annotation.JsonProperty("fileLocation")
    private final java.lang.String fileLocation;

    @com.fasterxml.jackson.annotation.JsonProperty("id")
    private final java.lang.Double id;

    @com.fasterxml.jackson.annotation.JsonProperty("previewSlug")
    private final java.lang.String previewSlug;

    @com.fasterxml.jackson.annotation.JsonProperty("previewUrl")
    private final java.lang.String previewUrl;

    @com.fasterxml.jackson.annotation.JsonProperty("updatedAt")
    private final java.lang.String updatedAt;

    @com.fasterxml.jackson.annotation.JsonProperty("version")
    private final java.lang.String version;

    Doc(Builder builder) {
      super(builder);
      this.approvedDocUrl = builder.getApprovedDocUrl();
      this.artifactId = builder.getArtifactId();
      this.createdAt = builder.getCreatedAt();
      this.fileLocation = builder.getFileLocation();
      this.id = builder.getId();
      this.previewSlug = builder.getPreviewSlug();
      this.previewUrl = builder.getPreviewUrl();
      this.updatedAt = builder.getUpdatedAt();
      this.version = builder.getVersion();
    }
  }

  @lombok.Getter
  @lombok.EqualsAndHashCode(callSuper = false)
  @lombok.ToString
  @com.fasterxml.jackson.annotation.JsonInclude(
    com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL
  )
  @com.fasterxml.jackson.databind.annotation.JsonDeserialize(
    builder = ArtifactResponse.Sdk.Builder.class
  )
  public static class Sdk extends io.github.kaposke.models.BaseModel {

    @lombok.Getter
    @lombok.Setter
    @lombok.experimental.Accessors(chain = true)
    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(
      buildMethodName = "buildWithoutValidation",
      withPrefix = "set"
    )
    public static class Builder extends io.github.kaposke.models.BaseModel.Builder {

      static final java.util.Set<java.util.Set<String>> REQUIRED_FIELDS_GROUPS;

      static {
        java.lang.String[][] requiredFieldsGroups = new java.lang.String[][] {
          new java.lang.String[] {
            "artifactId",
            "createdAt",
            "fileLocation",
            "id",
            "language",
            "updatedAt",
            "version",
          },
        };

        REQUIRED_FIELDS_GROUPS =
          java.util.Arrays
            .stream(requiredFieldsGroups)
            .map(group ->
              java.util.Arrays.stream(group).collect(java.util.stream.Collectors.toSet())
            )
            .collect(java.util.stream.Collectors.toSet());
      }

      @com.fasterxml.jackson.annotation.JsonProperty("artifactId")
      private java.lang.Double artifactId;

      @com.fasterxml.jackson.annotation.JsonProperty("createdAt")
      private java.lang.String createdAt;

      @com.fasterxml.jackson.annotation.JsonProperty("fileLocation")
      private java.lang.String fileLocation;

      @com.fasterxml.jackson.annotation.JsonProperty("id")
      private java.lang.Double id;

      @com.fasterxml.jackson.annotation.JsonProperty("language")
      private java.lang.String language;

      @com.fasterxml.jackson.annotation.JsonProperty("updatedAt")
      private java.lang.String updatedAt;

      @com.fasterxml.jackson.annotation.JsonProperty("version")
      private java.lang.String version;

      public Builder() {
        super(ValidationType.ALL_OF);
      }

      protected Builder(BaseModel.Builder.ValidationType validationType) {
        super(validationType);
      }

      public ArtifactResponse.Sdk build() {
        String validateMsg = validate();

        if (validateMsg != null) {
          throw new io.github.kaposke.exceptions.ApiException(validateMsg);
        }

        return buildWithoutValidation();
      }

      public ArtifactResponse.Sdk buildWithoutValidation() {
        return new ArtifactResponse.Sdk(this);
      }

      @Override
      protected java.util.Set<String> getNonNullInstanceFieldNames() {
        // Introspect the class to get a list of all declared fields.
        return java.util.Arrays
          .asList(this.getClass().getDeclaredFields())
          .stream()
          .filter(field -> {
            try {
              // Filter fields that are non-static and have values that are not null.
              return (
                !java.lang.reflect.Modifier.isStatic(field.getModifiers()) &&
                field.get(this) != null
              );
            } catch (IllegalArgumentException | IllegalAccessException e) {
              // This should never happen...

              throw new io.github.kaposke.exceptions.ApiException(
                "Unexpected exception thrown while accessing instance fields.",
                e
              );
            }
          })
          .map(java.lang.reflect.Field::getName)
          .collect(java.util.stream.Collectors.toSet());
      }

      @Override
      protected java.util.Set<java.util.Set<String>> getRequiredFieldsGroups() {
        return REQUIRED_FIELDS_GROUPS;
      }
    }

    @com.fasterxml.jackson.annotation.JsonProperty("artifactId")
    private final java.lang.Double artifactId;

    @com.fasterxml.jackson.annotation.JsonProperty("createdAt")
    private final java.lang.String createdAt;

    @com.fasterxml.jackson.annotation.JsonProperty("fileLocation")
    private final java.lang.String fileLocation;

    @com.fasterxml.jackson.annotation.JsonProperty("id")
    private final java.lang.Double id;

    @com.fasterxml.jackson.annotation.JsonProperty("language")
    private final java.lang.String language;

    @com.fasterxml.jackson.annotation.JsonProperty("updatedAt")
    private final java.lang.String updatedAt;

    @com.fasterxml.jackson.annotation.JsonProperty("version")
    private final java.lang.String version;

    Sdk(Builder builder) {
      super(builder);
      this.artifactId = builder.getArtifactId();
      this.createdAt = builder.getCreatedAt();
      this.fileLocation = builder.getFileLocation();
      this.id = builder.getId();
      this.language = builder.getLanguage();
      this.updatedAt = builder.getUpdatedAt();
      this.version = builder.getVersion();
    }
  }

  @lombok.Getter
  @lombok.Setter
  @lombok.experimental.Accessors(chain = true)
  @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(
    buildMethodName = "buildWithoutValidation",
    withPrefix = "set"
  )
  public static class Builder extends io.github.kaposke.models.BaseModel.Builder {

    static final java.util.Set<java.util.Set<String>> REQUIRED_FIELDS_GROUPS;

    static {
      java.lang.String[][] requiredFieldsGroups = new java.lang.String[][] {
        new java.lang.String[] {
          "artifactType",
          "artifactUrl",
          "bucketKey",
          "bucketName",
          "buildId",
          "createdAt",
          "error",
          "id",
          "status",
          "updatedAt",
        },
      };

      REQUIRED_FIELDS_GROUPS =
        java.util.Arrays
          .stream(requiredFieldsGroups)
          .map(group -> java.util.Arrays.stream(group).collect(java.util.stream.Collectors.toSet()))
          .collect(java.util.stream.Collectors.toSet());
    }

    @com.fasterxml.jackson.annotation.JsonProperty("artifactType")
    private java.lang.String artifactType;

    @com.fasterxml.jackson.annotation.JsonProperty("artifactUrl")
    private java.lang.String artifactUrl;

    @com.fasterxml.jackson.annotation.JsonProperty("bucketKey")
    private java.lang.String bucketKey;

    @com.fasterxml.jackson.annotation.JsonProperty("bucketName")
    private java.lang.String bucketName;

    @com.fasterxml.jackson.annotation.JsonProperty("buildId")
    private java.lang.Double buildId;

    @com.fasterxml.jackson.annotation.JsonProperty("createdAt")
    private java.lang.String createdAt;

    @com.fasterxml.jackson.annotation.JsonProperty("doc")
    private ArtifactResponse.Doc doc;

    @com.fasterxml.jackson.annotation.JsonProperty("error")
    private java.lang.String error;

    @com.fasterxml.jackson.annotation.JsonProperty("id")
    private java.lang.Double id;

    @com.fasterxml.jackson.annotation.JsonProperty("sdk")
    private ArtifactResponse.Sdk sdk;

    @com.fasterxml.jackson.annotation.JsonProperty("status")
    private java.lang.String status;

    @com.fasterxml.jackson.annotation.JsonProperty("updatedAt")
    private java.lang.String updatedAt;

    public Builder() {
      super(ValidationType.ALL_OF);
    }

    protected Builder(BaseModel.Builder.ValidationType validationType) {
      super(validationType);
    }

    public ArtifactResponse build() {
      String validateMsg = validate();

      if (validateMsg != null) {
        throw new io.github.kaposke.exceptions.ApiException(validateMsg);
      }

      return buildWithoutValidation();
    }

    public ArtifactResponse buildWithoutValidation() {
      return new ArtifactResponse(this);
    }

    @Override
    protected java.util.Set<String> getNonNullInstanceFieldNames() {
      // Introspect the class to get a list of all declared fields.
      return java.util.Arrays
        .stream(this.getClass().getDeclaredFields())
        .filter(field -> {
          try {
            // Filter fields that are non-static and have values that are not null.
            return (
              !java.lang.reflect.Modifier.isStatic(field.getModifiers()) && field.get(this) != null
            );
          } catch (IllegalArgumentException | IllegalAccessException e) {
            // This should never happen...

            throw new io.github.kaposke.exceptions.ApiException(
              "Unexpected exception thrown while accessing instance fields.",
              e
            );
          }
        })
        .map(java.lang.reflect.Field::getName)
        .collect(java.util.stream.Collectors.toSet());
    }

    @Override
    protected java.util.Set<java.util.Set<String>> getRequiredFieldsGroups() {
      return REQUIRED_FIELDS_GROUPS;
    }
  }

  @com.fasterxml.jackson.annotation.JsonProperty("artifactType")
  private final java.lang.String artifactType;

  @com.fasterxml.jackson.annotation.JsonProperty("artifactUrl")
  private final java.lang.String artifactUrl;

  @com.fasterxml.jackson.annotation.JsonProperty("bucketKey")
  private final java.lang.String bucketKey;

  @com.fasterxml.jackson.annotation.JsonProperty("bucketName")
  private final java.lang.String bucketName;

  @com.fasterxml.jackson.annotation.JsonProperty("buildId")
  private final java.lang.Double buildId;

  @com.fasterxml.jackson.annotation.JsonProperty("createdAt")
  private final java.lang.String createdAt;

  @com.fasterxml.jackson.annotation.JsonProperty("doc")
  private final ArtifactResponse.Doc doc;

  @com.fasterxml.jackson.annotation.JsonProperty("error")
  private final java.lang.String error;

  @com.fasterxml.jackson.annotation.JsonProperty("id")
  private final java.lang.Double id;

  @com.fasterxml.jackson.annotation.JsonProperty("sdk")
  private final ArtifactResponse.Sdk sdk;

  @com.fasterxml.jackson.annotation.JsonProperty("status")
  private final java.lang.String status;

  @com.fasterxml.jackson.annotation.JsonProperty("updatedAt")
  private final java.lang.String updatedAt;

  ArtifactResponse(Builder builder) {
    super(builder);
    this.artifactType = builder.getArtifactType();
    this.artifactUrl = builder.getArtifactUrl();
    this.bucketKey = builder.getBucketKey();
    this.bucketName = builder.getBucketName();
    this.buildId = builder.getBuildId();
    this.createdAt = builder.getCreatedAt();
    this.doc = builder.getDoc();
    this.error = builder.getError();
    this.id = builder.getId();
    this.sdk = builder.getSdk();
    this.status = builder.getStatus();
    this.updatedAt = builder.getUpdatedAt();
  }
}

==> LLTestJavaSDK-0.0.6-sources.jar: io/github/kaposke/models/ArtifactResponse.java <==
package io.github.kaposke.models;

@lombok.Getter
@lombok.EqualsAndHashCode(callSuper = false)
@lombok.ToString
@com.fasterxml.jackson.annotation.JsonInclude(
  com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL
)
@com.fasterxml.jackson.databind.annotation.JsonDeserialize(builder = ArtifactResponse.Builder.class)
public class ArtifactResponse extends io.github.kaposke.models.BaseModel {

  @lombok.Getter
  @lombok.EqualsAndHashCode(callSuper = false)
  @lombok.ToString
  @com.fasterxml.jackson.annotation.JsonInclude(
    com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL
  )
  @com.fasterxml.jackson.databind.annotation.JsonDeserialize(
    builder = ArtifactResponse.Doc.Builder.class
  )
  public static class Doc extends io.github.kaposke.models.BaseModel {

    @lombok.Getter
    @lombok.Setter
    @lombok.experimental.Accessors(chain = true)
    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(
      buildMethodName = "buildWithoutValidation",
      withPrefix = "set"
    )
    public static class Builder extends io.github.kaposke.models.BaseModel.Builder {

      static final java.util.Set<java.util.Set<String>> REQUIRED_FIELDS_GROUPS;

      static {
        java.lang.String[][] requiredFieldsGroups = new java.lang.String[][] {
          new java.lang.String[] {
            "artifactId",
            "createdAt",
            "fileLocation",
            "id",
            "previewSlug",
            "previewUrl",
            "updatedAt",
            "version",
          },
        };

        REQUIRED_FIELDS_GROUPS =
          java.util.Arrays
            .stream(requiredFieldsGroups)
            .map(group ->
              java.util.Arrays.stream(group).collect(java.util.stream.Collectors.toSet())
            )
            .collect(java.util.stream.Collectors.toSet());
      }

      @com.fasterxml.jackson.annotation.JsonProperty("approvedDocUrl")
      private java.lang.String approvedDocUrl;

      @com.fasterxml.jackson.annotation.JsonProperty("artifactId")
      private java.lang.Double artifactId;

      @com.fasterxml.jackson.annotation.JsonProperty("createdAt")
      private java.lang.String createdAt;

      @com.fasterxml.jackson.annotation.JsonProperty("fileLocation")
      private java.lang.String fileLocation;

      @com.fasterxml.jackson.annotation.JsonProperty("id")
      private java.lang.Double id;

      @com.fasterxml.jackson.annotation.JsonProperty("previewSlug")
      private java.lang.String previewSlug;

      @com.fasterxml.jackson.annotation.JsonProperty("previewUrl")
      private java.lang.String previewUrl;

      @com.fasterxml.jackson.annotation.JsonProperty("updatedAt")
      private java.lang.String updatedAt;

      @com.fasterxml.jackson.annotation.JsonProperty("version")
      private java.lang.String version;

      public Builder() {
        super(ValidationType.ALL_OF);
      }

      protected Builder(BaseModel.Builder.ValidationType validationType) {
        super(validationType);
      }

      public ArtifactResponse.Doc build() {
        String validateMsg = validate();

        if (validateMsg != null) {
          throw new io.github.kaposke.exceptions.ApiException(validateMsg);
        }

        return buildWithoutValidation();
      }

      public ArtifactResponse.Doc buildWithoutValidation() {
        return new ArtifactResponse.Doc(this);
      }

      @Override
      protected java.util.Set<String> getNonNullInstanceFieldNames() {
        // Introspect the class to get a list of all declared fields.
        return java.util.Arrays
          .asList(this.getClass().getDeclaredFields())
          .stream()
          .filter(field -> {
            try {
              // Filter fields that are non-static and have values that are not null.
              return (
                !java.lang.reflect.Modifier.isStatic(field.getModifiers()) &&
                field.get(this) != null
              );
            } catch (IllegalArgumentException | IllegalAccessException e) {
              // This should never happen...

              throw new io.github.kaposke.exceptions.ApiException(
                "Unexpected exception thrown while accessing instance fields.",
                e
              );
            }
          })
          .map(java.lang.reflect.Field::getName)
          .collect(java.util.stream.Collectors.toSet());
      }

      @Override
      protected java.util.Set<java.util.Set<String>> getRequiredFieldsGroups() {
        return REQUIRED_FIELDS_GROUPS;
      }
    }

    @com.fasterxml.jackson.annotation.JsonProperty("approvedDocUrl")
    private final java.lang.String approvedDocUrl;

    @com.fasterxml.jackson.annotation.JsonProperty("artifactId")
    private final java.lang.Double artifactId;

    @com.fasterxml.jackson.annotation.JsonProperty("createdAt")
    private final java.lang.String createdAt;

    @com.fasterxml.jackson.annotation.JsonProperty("fileLocation")
    private final java.lang.String fileLocation;

    @com.fasterxml.jackson.annotation.JsonProperty("id")
    private final java.lang.Double id;

    @com.fasterxml.jackson.annotation.JsonProperty("previewSlug")
    private final java.lang.String previewSlug;

    @com.fasterxml.jackson.annotation.JsonProperty("previewUrl")
    private final java.lang.String previewUrl;

    @com.fasterxml.jackson.annotation.JsonProperty("updatedAt")
    private final java.lang.String updatedAt;

    @com.fasterxml.jackson.annotation.JsonProperty("version")
    private final java.lang.String version;

    Doc(Builder builder) {
      super(builder);
      this.approvedDocUrl = builder.getApprovedDocUrl();
      this.artifactId = builder.getArtifactId();
      this.createdAt = builder.getCreatedAt();
      this.fileLocation = builder.getFileLocation();
      this.id = builder.getId();
      this.previewSlug = builder.getPreviewSlug();
      this.previewUrl = builder.getPreviewUrl();
      this.updatedAt = builder.getUpdatedAt();
      this.version = builder.getVersion();
    }
  }

  @lombok.Getter
  @lombok.EqualsAndHashCode(callSuper = false)
  @lombok.ToString
  @com.fasterxml.jackson.annotation.JsonInclude(
    com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL
  )
  @com.fasterxml.jackson.databind.annotation.JsonDeserialize(
    builder = ArtifactResponse.Sdk.Builder.class
  )
  public static class Sdk extends io.github.kaposke.models.BaseModel {

    @lombok.Getter
    @lombok.Setter
    @lombok.experimental.Accessors(chain = true)
    @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(
      buildMethodName = "buildWithoutValidation",
      withPrefix = "set"
    )
    public static class Builder extends io.github.kaposke.models.BaseModel.Builder {

      static final java.util.Set<java.util.Set<String>> REQUIRED_FIELDS_GROUPS;

      static {
        java.lang.String[][] requiredFieldsGroups = new java.lang.String[][] {
          new java.lang.String[] {
            "artifactId",
            "createdAt",
            "fileLocation",
            "id",
            "language",
            "updatedAt",
            "version",
          },
        };

        REQUIRED_FIELDS_GROUPS =
          java.util.Arrays
            .stream(requiredFieldsGroups)
            .map(group ->
              java.util.Arrays.stream(group).collect(java.util.stream.Collectors.toSet())
            )
            .collect(java.util.stream.Collectors.toSet());
      }

      @com.fasterxml.jackson.annotation.JsonProperty("artifactId")
      private java.lang.Double artifactId;

      @com.fasterxml.jackson.annotation.JsonProperty("createdAt")
      private java.lang.String createdAt;

      @com.fasterxml.jackson.annotation.JsonProperty("fileLocation")
      private java.lang.String fileLocation;

      @com.fasterxml.jackson.annotation.JsonProperty("id")
      private java.lang.Double id;

      @com.fasterxml.jackson.annotation.JsonProperty("language")
      private java.lang.String language;

      @com.fasterxml.jackson.annotation.JsonProperty("updatedAt")
      private java.lang.String updatedAt;

      @com.fasterxml.jackson.annotation.JsonProperty("version")
      private java.lang.String version;

      public Builder() {
        super(ValidationType.ALL_OF);
      }

      protected Builder(BaseModel.Builder.ValidationType validationType) {
        super(validationType);
      }

      public ArtifactResponse.Sdk build() {
        String validateMsg = validate();

        if (validateMsg != null) {
          throw new io.github.kaposke.exceptions.ApiException(validateMsg);
        }

        return buildWithoutValidation();
      }

      public ArtifactResponse.Sdk buildWithoutValidation() {
        return new ArtifactResponse.Sdk(this);
      }

      @Override
      protected java.util.Set<String> getNonNullInstanceFieldNames() {
        // Introspect the class to get a list of all declared fields.
        return java.util.Arrays
          .asList(this.getClass().getDeclaredFields())
          .stream()
          .filter(field -> {
            try {
              // Filter fields that are non-static and have values that are not null.
              return (
                !java.lang.reflect.Modifier.isStatic(field.getModifiers()) &&
                field.get(this) != null
              );
            } catch (IllegalArgumentException | IllegalAccessException e) {
              // This should never happen...

              throw new io.github.kaposke.exceptions.ApiException(
                "Unexpected exception thrown while accessing instance fields.",
                e
              );
            }
          })
          .map(java.lang.reflect.Field::getName)
          .collect(java.util.stream.Collectors.toSet());
      }

      @Override
      protected java.util.Set<java.util.Set<String>> getRequiredFieldsGroups() {
        return REQUIRED_FIELDS_GROUPS;
      }
    }

    @com.fasterxml.jackson.annotation.JsonProperty("artifactId")
    private final java.lang.Double artifactId;

    @com.fasterxml.jackson.annotation.JsonProperty("createdAt")
    private final java.lang.String createdAt;

    @com.fasterxml.jackson.annotation.JsonProperty("fileLocation")
    private final java.lang.String fileLocation;

    @com.fasterxml.jackson.annotation.JsonProperty("id")
    private final java.lang.Double id;

    @com.fasterxml.jackson.annotation.JsonProperty("language")
    private final java.lang.String language;

    @com.fasterxml.jackson.annotation.JsonProperty("updatedAt")
    private final java.lang.String updatedAt;

    @com.fasterxml.jackson.annotation.JsonProperty("version")
    private final java.lang.String version;

    Sdk(Builder builder) {
      super(builder);
      this.artifactId = builder.getArtifactId();
      this.createdAt = builder.getCreatedAt();
      this.fileLocation = builder.getFileLocation();
      this.id = builder.getId();
      this.language = builder.getLanguage();
      this.updatedAt = builder.getUpdatedAt();
      this.version = builder.getVersion();
    }
  }

  @lombok.Getter
  @lombok.Setter
  @lombok.experimental.Accessors(chain = true)
  @com.fasterxml.jackson.databind.annotation.JsonPOJOBuilder(
    buildMethodName = "buildWithoutValidation",
    withPrefix = "set"
  )
  public static class Builder extends io.github.kaposke.models.BaseModel.Builder {

    static final java.util.Set<java.util.Set<String>> REQUIRED_FIELDS_GROUPS;

    static {
      java.lang.String[][] requiredFieldsGroups = new java.lang.String[][] {
        new java.lang.String[] {
          "artifactType",
          "artifactUrl",
          "buildId",
          "createdAt",
          "error",
          "id",
          "remoteFileId",
          "status",
          "updatedAt",
        },
      };

      REQUIRED_FIELDS_GROUPS =
        java.util.Arrays
          .stream(requiredFieldsGroups)
          .map(group -> java.util.Arrays.stream(group).collect(java.util.stream.Collectors.toSet()))
          .collect(java.util.stream.Collectors.toSet());
    }

    @com.fasterxml.jackson.annotation.JsonProperty("artifactType")
    private java.lang.String artifactType;

    @com.fasterxml.jackson.annotation.JsonProperty("artifactUrl")
    private java.lang.String artifactUrl;

    @com.fasterxml.jackson.annotation.JsonProperty("buildId")
    private java.lang.Double buildId;

    @com.fasterxml.jackson.annotation.JsonProperty("createdAt")
    private java.lang.String createdAt;

    @com.fasterxml.jackson.annotation.JsonProperty("doc")
    private ArtifactResponse.Doc doc;

    @com.fasterxml.jackson.annotation.JsonProperty("error")
    private java.lang.String error;

    @com.fasterxml.jackson.annotation.JsonProperty("id")
    private java.lang.Double id;

    @com.fasterxml.jackson.annotation.JsonProperty("remoteFileId")
    private java.lang.Double remoteFileId;

    @com.fasterxml.jackson.annotation.JsonProperty("sdk")
    private ArtifactResponse.Sdk sdk;

    @com.fasterxml.jackson.annotation.JsonProperty("status")
    private java.lang.String status;

    @com.fasterxml.jackson.annotation.JsonProperty("updatedAt")
    private java.lang.String updatedAt;

    public Builder() {
      super(ValidationType.ALL_OF);
    }

    protected Builder(BaseModel.Builder.ValidationType validationType) {
      super(validationType);
    }

    public ArtifactResponse build() {
      String validateMsg = validate();

      if (validateMsg != null) {
        throw new io.github.kaposke.exceptions.ApiException(validateMsg);
      }

      return buildWithoutValidation();
    }

    public ArtifactResponse buildWithoutValidation() {
      return new ArtifactResponse(this);
    }

    @Override
    protected java.util.Set<String> getNonNullInstanceFieldNames() {
      // Introspect the class to get a list of all declared fields.
      return java.util.Arrays
        .stream(this.getClass().getDeclaredFields())
        .filter(field -> {
          try {
            // Filter fields that are non-static and have values that are not null.
            return (
              !java.lang.reflect.Modifier.isStatic(field.getModifiers()) && field.get(this) != null
            );
          } catch (IllegalArgumentException | IllegalAccessException e) {
            // This should never happen...

            throw new io.github.kaposke.exceptions.ApiException(
              "Unexpected exception thrown while accessing instance fields.",
              e
            );
          }
        })
        .map(java.lang.reflect.Field::getName)
        .collect(java.util.stream.Collectors.toSet());
    }

    @Override
    protected java.util.Set<java.util.Set<String>> getRequiredFieldsGroups() {
      return REQUIRED_FIELDS_GROUPS;
    }
  }

  @com.fasterxml.jackson.annotation.JsonProperty("artifactType")
  private final java.lang.String artifactType;

  @com.fasterxml.jackson.annotation.JsonProperty("artifactUrl")
  private final java.lang.String artifactUrl;

  @com.fasterxml.jackson.annotation.JsonProperty("buildId")
  private final java.lang.Double buildId;

  @com.fasterxml.jackson.annotation.JsonProperty("createdAt")
  private final java.lang.String createdAt;

  @com.fasterxml.jackson.annotation.JsonProperty("doc")
  private final ArtifactResponse.Doc doc;

  @com.fasterxml.jackson.annotation.JsonProperty("error")
  private final java.lang.String error;

  @com.fasterxml.jackson.annotation.JsonProperty("id")
  private final java.lang.Double id;

  @com.fasterxml.jackson.annotation.JsonProperty("remoteFileId")
  private final java.lang.Double remoteFileId;

  @com.fasterxml.jackson.annotation.JsonProperty("sdk")
  private final ArtifactResponse.Sdk sdk;

  @com.fasterxml.jackson.annotation.JsonProperty("status")
  private final java.lang.String status;

  @com.fasterxml.jackson.annotation.JsonProperty("updatedAt")
  private final java.lang.String updatedAt;

  ArtifactResponse(Builder builder) {
    super(builder);
    this.artifactType = builder.getArtifactType();
    this.artifactUrl = builder.getArtifactUrl();
    this.buildId = builder.getBuildId();
    this.createdAt = builder.getCreatedAt();
    this.doc = builder.getDoc();
    this.error = builder.getError();
    this.id = builder.getId();
    this.remoteFileId = builder.getRemoteFileId();
    this.sdk = builder.getSdk();
    this.status = builder.getStatus();
    this.updatedAt = builder.getUpdatedAt();
  }
}
